@@ -67,7 +67,7 @@ class ProcessContext:
         PROCESS_CONTEXT_DISABLE_ALL_TELEMETRY to opt out.
 
     CommandLine:
-        xdoctest -m kwutil.process_context ProcessContext
+        kernprof -lvp kwutil -m xdoctest -m kwutil.process_context ProcessContext:0
 
     Example:
         >>> # xdoctest: +REQUIRES(module:psutil)
@@ -92,9 +92,10 @@ class ProcessContext:
 
     Example:
         >>> # xdoctest: +REQUIRES(module:psutil)
+        >>> # xdoctest: +REQUIRES(module:codecarbon)
         >>> from kwutil.process_context import *
         >>> # flush can measure intermediate progress
-        >>> self = ProcessContext(track_emissions=True)
+        >>> self = ProcessContext(track_emissions='offline')
         >>> self.add_disk_info('.')
         >>> obj1 = self.start().flush()
         >>> obj1_orig = obj1.copy()
@@ -231,7 +232,7 @@ class ProcessContext:
         Experimental use as a decorator.
 
         CommandLine:
-            xdoctest -m kwutil.process_context ProcessContext.__call__
+            kernprof -lvp -p kwutil -m xdoctest -m kwutil.process_context ProcessContext.__call__
 
         Example:
             >>> # xdoctest: +REQUIRES(module:psutil)
@@ -351,8 +352,17 @@ class ProcessContext:
         if not self.enable_most_telemetry:
             return {}
         try:
-            import cpuinfo
-            _cpu_info = cpuinfo.get_cpu_info()
+            # Calling `get_cpu_info` is very slow because it starts a new
+            # python process, so to avoid some overhead we cache the result
+            # It would be nice if Cacher had the expires property.
+            import ubelt as ub
+            cacher = ub.Cacher('cpuinfo_cache', appname='kwutil/cache',
+                               verbose=0)
+            _cpu_info = cacher.tryload()
+            if _cpu_info is None:
+                import cpuinfo
+                _cpu_info = cpuinfo.get_cpu_info()
+                cacher.save(_cpu_info)
             cpu_info = {
                 "cpu_brand": _cpu_info["brand_raw"],
                 "cpu_count": _cpu_info["count"],
