@@ -20,6 +20,7 @@ Related Work:
 """
 import ubelt as ub
 import weakref
+from functools import cached_property
 
 
 class DotDict(ub.UDict):
@@ -49,19 +50,21 @@ class DotDict(ub.UDict):
         >>> assert nested != self
         >>> assert recon == self
     """
+    # def __init__(self, /, *args, **kwargs):
+    #     super().__init__(*args, **kwargs)
 
-    def __init__(self, /, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    @cached_property
+    def _trie_cache(self):
         # The prefix tree backend allows us to efficiently query items as if
         # the flat data structure was nested.
         # FIXME: we do not invalidate the cache on mutations yet.
         # NOTE: using the trie backend is almost always slower than a loop,
         # theoretically it should be faster, but we need a better
         # implementation
-        self._trie_cache = _TrieCache(self)
+        return _TrieCache(self)
 
     @classmethod
-    def from_nested(cls, data):
+    def from_nested(cls, data, prefix=None):
         """
         Construct this flat representation from a nested one
 
@@ -104,24 +107,36 @@ class DotDict(ub.UDict):
             >>>         {'score': 3},
             >>>     ]}
             >>> from kwutil.util_dotdict import DotDict
-            >>> flat = DotDict.from_nested(data)
-            >>> print(f'flat = {ub.urepr(flat, nl=2)}')
+            >>> flat = DotDict.from_nested(data, prefix='my')
+            >>> print(f'flat = {ub.urepr(flat, nl=2, sort=1)}')
             flat = {
-                'type': 'measure',
-                'results': [
+                'my.results': [
                     {'score': 1},
                     {'score': 2},
                     {'score': 3},
                 ],
+                'my.type': 'measure',
             }
         """
+        # flat = cls()
+        # walker = ub.IndexableWalker(data, list_cls=tuple())
+        # for path, value in walker:
+        #     if not isinstance(value, dict):
+        #         spath = list(map(str, path))
+        #         key = '.'.join(spath)
+        #         flat[key] = value
+        ###
+        # Slightly faster than the above implementation
         flat = cls()
-        walker = ub.IndexableWalker(data, list_cls=tuple())
-        for path, value in walker:
-            if not isinstance(value, dict):
-                spath = list(map(str, path))
-                key = '.'.join(spath)
-                flat[key] = value
+        stack = [(prefix if prefix else "", data)]
+        while stack:
+            prefix, node = stack.pop()
+            if isinstance(node, dict):
+                for k, v in reversed(node.items()):
+                    key = f"{prefix}.{k}" if prefix else str(k)
+                    stack.append((key, v))
+            else:
+                flat[prefix] = node
         return flat
 
     def to_nested(self):
@@ -350,7 +365,7 @@ class DotDict(ub.UDict):
         """
         if index == 0:
             # Faster special case
-            new = self.__class__((prefix + '.' + k, v) for k, v in self.items())
+            new = self.__class__((f'{prefix}.{k}', v) for k, v in self.items())
         else:
             def _generate_new_items():
                 sep = '.'
