@@ -2,6 +2,7 @@
 json utilities for debugging serializability and attempting to ensure it in
 some cases.
 """
+import os
 import copy
 import decimal
 import fractions
@@ -333,32 +334,64 @@ class Json:
         >>> # xdoctest: +REQUIRES(module:ujson)
         >>> data2 = Json.loads(text1, backend='ujson')
         >>> assert data2 == data
+        >>> # with orjson
+        >>> # xdoctest: +REQUIRES(module:orjson)
+        >>> data2 = Json.loads(text1, backend='orjson')
+        >>> assert data2 == data
     """
 
+    @staticmethod
+    def _load_filepointer(filepointer, backend='stdlib'):
+        if backend == 'stdlib':
+            import json
+            data = json.load(filepointer)
+        elif backend == 'ujson':
+            import ujson
+            data = ujson.load(filepointer)
+        elif backend == 'orjson':
+            import orjson
+            data = orjson.loads(filepointer.read())
+        else:
+            raise NotImplementedError(backend)
+        return data
+
     @staticmethod
     def load(file, backend='stdlib'):
-        import os
+        """
+        Load json from a filepointer or filepath.
+
+        Args:
+            file (Path | str | _io._IOBase):
+                a path to a file, or an open file descriptor in bytes or str
+                mode. bytes mode is more efficient.
+
+        Example:
+            >>> import kwutil
+            >>> import io
+            >>> # test loading from string or byte file pointers
+            >>> data = b'["hello", {"from": "json"}]'
+            >>> r1 = kwutil.Json.load(io.BytesIO(data), backend='stdlib')
+            >>> r2 = kwutil.Json.load(io.StringIO(data.decode()), backend='stdlib')
+            >>> # xdoctest: +REQUIRES(module:ujson)
+            >>> r3 = kwutil.Json.load(io.BytesIO(data), backend='ujson')
+            >>> r4 = kwutil.Json.load(io.StringIO(data.decode()), backend='ujson')
+            >>> # xdoctest: +REQUIRES(module:orjson)
+            >>> r3 = kwutil.Json.load(io.BytesIO(data), backend='orjson')
+            >>> r4 = kwutil.Json.load(io.StringIO(data.decode()), backend='orjson')
+            >>> assert r1 == r2 == r3 == r4
+        """
         if isinstance(file, (str, os.PathLike)):
             fpath = file
-            with open(fpath, 'r') as fp:
-                return Json.load(fp, backend=backend)
+            with open(fpath, 'rb') as fp:
+                return Json._load_filepointer(fp, backend=backend)
         else:
-            if backend == 'stdlib':
-                import json
-                data = json.load(file)
-            elif backend == 'ujson':
-                import ujson
-                data = ujson.load(file)
-            elif backend == 'orjson':
-                import orjson
-                with open(file, 'r') as file:
-                    data = orjson.loads(file.read())
-            else:
-                raise NotImplementedError(backend)
-            return data
+            return Json._load_filepointer(file, backend=backend)
 
     @staticmethod
     def loads(text, backend='stdlib'):
+        """
+        Decode json from bytes or text
+        """
         if backend == 'stdlib':
             import json
             data = json.loads(text)
