@@ -502,8 +502,8 @@ class ProgressManager(BaseProgIterManager):
         >>> # Test complex example over a grid of parameters
         >>> from kwutil.util_progress import ProgressManager, ProgIter2
         >>> import time
-        >>> delay = 0.000005
-        >>> N_inner = 300
+        >>> delay = 0.000001
+        >>> N_inner = 100
         >>> N_outer = 11
         >>> basis = {
         >>>     'with_info': [0, 1],
@@ -646,12 +646,14 @@ def _progman_test_multiple_managers():
 
     pman1 = util_progress.ProgressManager()
 
+    factor = 0.001
+
     with pman1:
         print(f'pman1._is_main_manager={pman1._is_main_manager}')
         print('Print before loop 1')
 
         for i in pman1.progiter(range(100), desc='PMAN(1) Iter(1)'):
-            time.sleep(0.01)
+            time.sleep(0.01 * factor)
 
         print('Print after loop 1 #1')
         print('Print after loop 1 #2')
@@ -660,7 +662,7 @@ def _progman_test_multiple_managers():
         print('Print before loop 2')
 
         for i in pman1.progiter(range(100), desc='PMAN(1) Iter(2)'):
-            time.sleep(0.009)
+            time.sleep(0.009 * factor)
 
         print('Print after loop 2 #1')
         print('Print after loop 2 #2')
@@ -671,7 +673,7 @@ def _progman_test_multiple_managers():
 
         for idx in range(2):
             for i in pman2.progiter(range(100), desc=f'PMAN(2) Iter({idx})'):
-                time.sleep(0.008)
+                time.sleep(0.008 * factor)
 
         print(f'pman2._is_main_manager={pman2._is_main_manager}')
         print(f'pman1._is_main_manager={pman1._is_main_manager}')
@@ -684,7 +686,7 @@ def _progman_test_multiple_managers():
         print(f'pman3._is_main_manager={pman3._is_main_manager}')
         for idx in range(3):
             for i in pman2.progiter(range(100), desc=f'PMAN(3) Iter({idx})'):
-                time.sleep(0.005)
+                time.sleep(0.005 * factor)
         print(f'pman3._is_main_manager={pman3._is_main_manager}')
 
     print(f'pman1._is_main_manager={pman1._is_main_manager}')
@@ -702,7 +704,7 @@ def _progman_test_multiple_managers_tree():
     import time
     from kwutil import util_progress
 
-    sleep_time = 0.001
+    sleep_time = 0.001 * 0.001
 
     def _nested_loop(max_depth=0):
 
